========
Overview
========

.. image:: https://img.shields.io/pypi/v/inferiot.svg
    :target: https://pypi.python.org/pypi/inferiot
    :alt: Latest PyPI version

.. image:: Fasle.png
   :target: Fasle
   :alt: Latest Travis CI build status


Connect to Infer IoT Center using Python

* Free software: MIT license

Installation
============

::

    pip install inferiot

You can also install the in-development version with::

    pip install https://github.com/prafulmaka/inferiot



Authors
=============

InferIoT was written by Praful Maka, Mohammad Sameer Beig, John Groboske, Otu Ekanem and Daniel Gallagher.